@@ -27,7 +27,8 @@ def waiting(rw, head_str=None):
     while rw >= 0:
         m, s = divmod(rw, 60)
         h, m = divmod(m, 60)
-        print(f'{head_str}: [ {red(f"{h}:{m}:{s}")} ]\r', end='') if head_str else print(f'[ {red(f"{h}:{m}:{s}")} ]\r', end='')
+        print(f'{head_str}: [ {red(f"{h}:{m}:{s}")} ]\r', end='') if head_str else print(f'[ {red(f"{h}:{m}:{s}")} ]\r',
+                                                                                         end='')
         rw -= 1
         time.sleep(1)
     # print()
@@ -78,9 +79,9 @@ def get_rate(func, unit="auto", refresh_rate="s"):
     return k_info, n_in, n_out
 
 
-def start(ip_keys, print_out=True, unit="auto", refresh_rate="s", push_redis=False, target_redis_params=None):
+def start(ip_keys, return_only=True, unit="auto", refresh_rate="s", push_redis=False, target_redis_params=None, no_print_out=True):
     unit = unit.lower()
-    if print_out:
+    if not return_only:
         target_redis_params = target_redis_params if target_redis_params else [default_redis_params()]
         if not isinstance(target_redis_params, list):
             target_redis_params = [target_redis_params]
@@ -106,16 +107,16 @@ def start(ip_keys, print_out=True, unit="auto", refresh_rate="s", push_redis=Fal
                                                      "time": tell_the_datetime(),
                                                      "hostname": hostname,
                                                      "ip": ip_info.get('ip'),
-                                                     "location": location_info.get('location') or f"{ip_info.get('city')} - {ip_info.get('country')}",
+                                                     "location": location_info.get(
+                                                         'location') or f"{ip_info.get('city')} - {ip_info.get('country')}",
                                                      } for i_key in s_key_set})
                     for trp in target_redis_params:
-                        params = {
-                            "trp": trp,
-                            "insert_obj": insert_obj
-                        }
                         thread = ComThread(
                             function=push_to_server,
-                            params=params
+                            params={
+                                "trp": trp,
+                                "insert_obj": insert_obj
+                            }
                         )
                         try:
                             thread.setDaemon(True)
@@ -123,16 +124,17 @@ def start(ip_keys, print_out=True, unit="auto", refresh_rate="s", push_redis=Fal
                         except Exception as E:
                             print(f"{red('Error in push data to server redis')}: \n{E}")
                             return
-                s_out = "; ".join(
-                    [f"{hred(ky)}: [ in: {hgreen(ne_in.get(ky))}, out: {hblue(ne_out.get(ky))} ]" for ky in s_key_set])
-                s_out = f"{'-'*42}{tell_the_datetime()} {s_out}"
-                try:
-                    length = os.get_terminal_size().columns - (len(s_out)-13*2)
-                except:
-                    length = 100 - (len(s_out)-13*2)
-                if length < 0:
-                    length = 0
-                print(f"{s_out}{' '*length}\r", end='')
+                if not no_print_out:
+                    s_out = "; ".join(
+                        [f"{hred(ky)}: [ in: {hgreen(ne_in.get(ky))}, out: {hblue(ne_out.get(ky))} ]" for ky in s_key_set])
+                    s_out = f"{'-' * 42}{tell_the_datetime()} {s_out}"
+                    try:
+                        length = os.get_terminal_size().columns - (len(s_out) - 13 * 2)
+                    except Exception as E:
+                        length = 100 - (len(s_out) - 13 * 2)
+                    if length < 0:
+                        length = 0
+                    print(f"{s_out}{' ' * length}\r", end='')
             except KeyboardInterrupt:
                 print()
                 exit()
@@ -150,9 +152,7 @@ def start(ip_keys, print_out=True, unit="auto", refresh_rate="s", push_redis=Fal
         return {ky: [ne_in.get(ky), ne_out.get(ky), unit, tell_the_datetime()] for ky in s_key_set}
 
 
-def push_to_server(params_data):
-    trp = params_data.get("trp")
-    insert_obj = params_data.get("insert_obj")
+def push_to_server(trp, insert_obj):
     get_redis_cli(trp).rpush(trp.get('insert_key', "NetRecs"), insert_obj)
 
 
@@ -180,6 +180,8 @@ def record_starter():
                              'now是后面直接跟上>>>>参数字典，例如：now>>>>{"host": "127.0.0.1", "port": ..., "db": ...}，'
                              'now方式仅限测试\n'
                              f'默认input\n')
+    parser.add_argument("-no", "--no_print_out", dest="no_print_out", action="store_true",
+                        help=f'{da} 控制是否输出到终端，以服务方式启动时默认不输出\n')
     args = parser.parse_args()
     if args.place_script_only:
         return start_up_check(dont_ask=True)
@@ -220,11 +222,12 @@ def record_starter():
                 print("no values in local redis key: NetRec_key_params")
                 exit(1)
     # sys.stdout = Logger(os.path.join(os.getcwd(), f"netrecord_{tell_the_datetime(compact_mode=True)}.log"))
-    start(n_devices, print_out=True, unit=unit, refresh_rate=refresh_rate, push_redis=push_to_redis, target_redis_params=key_params)
+    start(n_devices, return_only=True, unit=unit, refresh_rate=refresh_rate, push_redis=push_to_redis,
+          target_redis_params=key_params, no_print_out=args.no_print_out)
 
 
 if __name__ == '__main__':
     # s_keys = sys.argv[1:] or ["eth0", "enp2s0"]
     # res = start(s_keys, print_out=False, unit="auto")
     # print(res)
-    record_starter()
\ No newline at end of file
+    record_starter()
