@@ -25,12 +25,10 @@ def record_starter_server():
                              'now方式仅限测试\n'
                              f'默认input\n')
     args = parser.parse_args()
-    n_devices = [x.strip() for x in args.net_devices.split(",")]
     unit = args.unit
     refresh_rate = args.refresh_rate.lower()
     push_to_redis = args.push_redis
     key_params_mode = args.key_params
-    push_to_redis = True if push_to_redis == 'y' or push_to_redis is None else False
     try:
         log_dir = "~/"
         file_name = "NetTraRec.py"
